package de.juplo.plugins.hibernate;

/*
 * Copyright 2001-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.File;
import java.util.Map;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.hibernate.boot.spi.MetadataImplementor;
import org.hibernate.engine.config.spi.ConfigurationService;
import org.hibernate.service.ServiceRegistry;
import org.hibernate.tool.schema.internal.ExceptionHandlerCollectingImpl;
import org.hibernate.tool.schema.spi.ExecutionOptions;
import org.hibernate.tool.schema.spi.SchemaManagementTool;
import org.hibernate.tool.schema.spi.SchemaManagementToolCoordinator;


/**
 * Validate a database-schema against the configured mappings.
 *
 * @goal validate
 * @phase process-classes
 * @threadSafe
 * @requiresDependencyResolution runtime
 */
public class ValidateMojo extends AbstractSchemaMojo
{
  @Override
  public final void execute()
    throws
      MojoFailureException,
      MojoExecutionException
  {
    super.execute(null);
  }


  @Override
  ExceptionHandlerCollectingImpl build(final MetadataImplementor metadata)
      throws
        MojoExecutionException,
        MojoFailureException
  {
    ServiceRegistry registry =
        metadata.getMetadataBuildingOptions().getServiceRegistry();
    SchemaManagementTool tool = registry.getService(SchemaManagementTool.class);

    ExceptionHandlerCollectingImpl handler =
        new ExceptionHandlerCollectingImpl();

    ExecutionOptions options =
        SchemaManagementToolCoordinator.buildExecutionOptions(
            registry
                .getService(ConfigurationService.class)
                .getSettings(),
            handler
            );
    Map config = options.getConfigurationValues();

    tool.getSchemaValidator(config).doValidation(metadata, options);

    return handler;
  }
}
